
module top(
    
    input sw1,//L25
    input sw3,//R22
    input sw4,//T22
    output sfp_tx_disable, 
    output [7:0]     xgmii_rxc,
    output [63:0]    xgmii_rxd  ,
    output [15:0]   debug_vector_o
    
);
    
    assign sfp_tx_disable = 1'b0;

    wire        xgmii_tx_pll_lock_o;
    wire        s_lock_o;
    reg  [7:0]  xgmii_txc;
    reg  [63:0] xgmii_txd;
    wire        block_lock; 
    wire        hi_ber; 
    wire        pcs_status;
    wire        clear_ber_count;
    wire [5:0]  ber_count; 
    wire        clear_errored_block_count;
    wire [7:0]  errored_block_count; 
    wire        ref_clk;
    wire        clk_out0_o;
    wire        clk_out1_o;

    SerDes_Top u_SerDes_Top(
        .Ten_Giga_Serial_Ethernet_Top_xgmii_rxc_o(xgmii_rxc), //output [7:0] Ten_Giga_Serial_Ethernet_Top_xgmii_rxc_o
        .Ten_Giga_Serial_Ethernet_Top_xgmii_rxd_o(xgmii_rxd), //output [63:0] Ten_Giga_Serial_Ethernet_Top_xgmii_rxd_o
        .Ten_Giga_Serial_Ethernet_Top_ref_clk_o(ref_clk), //output Ten_Giga_Serial_Ethernet_Top_ref_clk_o
        .Ten_Giga_Serial_Ethernet_Top_clk_out0_o(clk_out0_o), //output Ten_Giga_Serial_Ethernet_Top_clk_out0_o
        .Ten_Giga_Serial_Ethernet_Top_clk_out1_o(clk_out1_o), //output Ten_Giga_Serial_Ethernet_Top_clk_out1_o
        .Ten_Giga_Serial_Ethernet_Top_block_lock_o(block_lock), //output Ten_Giga_Serial_Ethernet_Top_block_lock_o
        .Ten_Giga_Serial_Ethernet_Top_hi_ber_o(hi_ber), //output Ten_Giga_Serial_Ethernet_Top_hi_ber_o
        .Ten_Giga_Serial_Ethernet_Top_pcs_status_o(pcs_status), //output Ten_Giga_Serial_Ethernet_Top_pcs_status_o
        .Ten_Giga_Serial_Ethernet_Top_ber_count_o(ber_count), //output [5:0] Ten_Giga_Serial_Ethernet_Top_ber_count_o
        .Ten_Giga_Serial_Ethernet_Top_errored_block_count_o(errored_block_count), //output [7:0] Ten_Giga_Serial_Ethernet_Top_errored_block_count_o
        .Ten_Giga_Serial_Ethernet_Top_debug_vector_o(debug_vector_o), //output [15:0] Ten_Giga_Serial_Ethernet_Top_debug_vector_o
        .Ten_Giga_Serial_Ethernet_Top_rx_rstn_i(sw3), //input Ten_Giga_Serial_Ethernet_Top_rx_rstn_i
        .Ten_Giga_Serial_Ethernet_Top_tx_rstn_i(sw4), //input Ten_Giga_Serial_Ethernet_Top_tx_rstn_i
        .Ten_Giga_Serial_Ethernet_Top_signal_detect_i(1'b1), //input Ten_Giga_Serial_Ethernet_Top_signal_detect_i
        .Ten_Giga_Serial_Ethernet_Top_xgmii_rx_clk_i(xgmii_rx_clk), //input Ten_Giga_Serial_Ethernet_Top_xgmii_rx_clk_i
        .Ten_Giga_Serial_Ethernet_Top_xgmii_tx_clk_i(xgmii_tx_clk), //input Ten_Giga_Serial_Ethernet_Top_xgmii_tx_clk_i
        .Ten_Giga_Serial_Ethernet_Top_xgmii_rx_clk_ready_i(1'b1), //input Ten_Giga_Serial_Ethernet_Top_xgmii_rx_clk_ready_i
        .Ten_Giga_Serial_Ethernet_Top_xgmii_tx_clk_ready_i(1'b1), //input Ten_Giga_Serial_Ethernet_Top_xgmii_tx_clk_ready_i
        .Ten_Giga_Serial_Ethernet_Top_xgmii_txc_i(xgmii_txc), //input [7:0] Ten_Giga_Serial_Ethernet_Top_xgmii_txc_i
        .Ten_Giga_Serial_Ethernet_Top_xgmii_txd_i(xgmii_txd), //input [63:0] Ten_Giga_Serial_Ethernet_Top_xgmii_txd_i
        .Ten_Giga_Serial_Ethernet_Top_clear_ber_count_i(clear_ber_count), //input Ten_Giga_Serial_Ethernet_Top_clear_ber_count_i
        .Ten_Giga_Serial_Ethernet_Top_clear_errored_block_count_i(clear_errored_block_count) //input Ten_Giga_Serial_Ethernet_Top_clear_errored_block_count_i
    );


    assign clear_ber_count = 1'b0;
    assign clear_errored_block_count = 1'b0;
    assign xgmii_rx_clk = ref_clk;
    assign xgmii_tx_clk = ref_clk;

    //----------Pattern Generate----------
    reg [7:0] tx_cnt;
    reg [7:0] initial_byte;
    reg [63:0] txdata;
    always@(posedge xgmii_tx_clk) begin
        if (!sw1) begin
            tx_cnt <= 8'd0;
            initial_byte <= 8'hab;
        end
        else begin
            tx_cnt <= tx_cnt + 1;
            if (tx_cnt == 0 || tx_cnt == 1) begin //transmit IDLE
                xgmii_txc <= 8'hff;
                xgmii_txd <= {8{8'h07}};
            end
            else if (tx_cnt == 2) begin //transmit Preamble
                xgmii_txc <= 8'h01;
                xgmii_txd <= {8'hd5,{6{8'h55}},8'hfb};
                txdata[7:0]   <= initial_byte + 0;
                txdata[15:8]  <= initial_byte + 1;
                txdata[23:16] <= initial_byte + 2;
                txdata[31:24] <= initial_byte + 3;
                txdata[39:32] <= initial_byte + 4;
                txdata[47:40] <= initial_byte + 5;
                txdata[55:48] <= initial_byte + 6;
                txdata[63:56] <= initial_byte + 7;
            end
            else if (tx_cnt <= 100) begin //transmit data
                xgmii_txc <= 8'h0;
                xgmii_txd <= txdata;
                txdata[7:0]   <= txdata[7:0]   + 8;
                txdata[15:8]  <= txdata[15:8]  + 8;
                txdata[23:16] <= txdata[23:16] + 8;
                txdata[31:24] <= txdata[31:24] + 8;
                txdata[39:32] <= txdata[39:32] + 8;
                txdata[47:40] <= txdata[47:40] + 8;
                txdata[55:48] <= txdata[55:48] + 8;
                txdata[63:56] <= txdata[63:56] + 8;
            end
            else begin
                xgmii_txc <= 8'hff;
                xgmii_txd <= {{7{8'h07}},8'hfd};
                tx_cnt <= 0;
            end
        end
    end


endmodule

