`timescale 1ns/1ps

module tb;

//------Simulate Serdes Clock and XGMII Clock--------------
localparam hs_period = 0.097; 
reg hs_clk = 0; 

initial begin
    forever #(hs_period) hs_clk = ~hs_clk;
end

reg serdes_clk = 0;
reg ref_clk = 0;

reg [6:0] serdes_clk_cnt = 0;
reg [6:0] ref_clk_cnt = 0;

always@(hs_clk) begin
    if (serdes_clk_cnt == 31) begin
        serdes_clk_cnt <= 0;
        serdes_clk <= ~serdes_clk;
    end
    else begin
        serdes_clk_cnt <= serdes_clk_cnt + 1;
    end

    if (ref_clk_cnt == 32) begin
        ref_clk_cnt <= 0;
        ref_clk <= ~ref_clk;
    end
    else begin
        ref_clk_cnt <= ref_clk_cnt + 1;
    end
end

//-------Instantiate IP----------
reg [7:0] xgmii_txc;
reg [63:0] xgmii_txd;
wire [7:0] xgmii_rxc;
wire [63:0] xgmii_rxd;
wire xgmii_clk;
wire ref_clk_o;
wire block_lock;
wire [79:0] serdes_txdata;
wire [87:0] serdes_rxdata;
reg serdes_pll_lock = 1'b0;
reg serdes_rx_lock = 1'b0;
reg serdes_data_valid = 1'b0;

assign xgmii_clk = ref_clk_o;
assign serdes_rxdata = (serdes_data_valid) ? serdes_txdata : 88'b0;


Ten_Giga_Serial_Ethernet_Top dut
(  
    .rx_rstn_i(1'b1),                    //input           
    .tx_rstn_i(1'b1),                    //input           
    .signal_detect_i(1'b1),              //input           
    .xgmii_rx_clk_i(xgmii_clk),          //input           
    .xgmii_tx_clk_i(xgmii_clk),          //input           
    .xgmii_rx_clk_ready_i(1'b1),         //input           
    .xgmii_tx_clk_ready_i(1'b1),         //input           
    .xgmii_txc_i(xgmii_txc),             //input [7:0]     
    .xgmii_txd_i(xgmii_txd),             //input [63:0]    
    .xgmii_rxc_o(xgmii_rxc),             //output [7:0]    
    .xgmii_rxd_o(xgmii_rxd),             //output [63:0]   
    .ref_clk_o(ref_clk_o),               //output          
    .clk_out0_o(),                       //output          
    .clk_out1_o(),                       //output          
    .block_lock_o(block_lock),           //output          
    .hi_ber_o(),                         //output          
    .pcs_status_o(),                     //output          
    .clear_ber_count_i(1'b0),            //input           
    .ber_count_o(),                      //output [5:0]    
    .clear_errored_block_count_i(1'b0),  //input           
    .errored_block_count_o(),            //output [7:0]    
    .debug_vector_o(),                   //output [15:0]   
    .serdes_pma_rx_lock_i(serdes_rx_lock),         //input           
    .serdes_qpll0_pll_lock_i(serdes_pll_lock),      //input           
    .serdes_qpll1_pll_lock_i(serdes_pll_lock),      //input           
    .serdes_cpll_pll_lock_i(serdes_pll_lock),       //input           
    .serdes_pcs_tx_clk_i(serdes_clk),    //input           
    .serdes_pcs_tx_clk_o(),              //output          
    .serdes_txdata_o(serdes_txdata),     //output [79:0]   
    .serdes_pcs_rx_clk_i(serdes_clk),    //input           
    .serdes_pcs_rx_clk_o(),              //output          
    .serdes_rxdata_i(serdes_rxdata),     //input [87:0]    
    .serdes_refclk0_i(ref_clk),          //input           
    .serdes_refclk1_i(ref_clk),          //input           
    .serdes_pma_rstn_o(),                //output          
    .serdes_pcs_tx_rst_o(),              //output          
    .serdes_pcs_rx_rst_o(),              //output          
    .serdes_pcs_rx_rden_o(),             //output          
    .serdes_pcs_rx_aempty_i(),           //input           
    .serdes_pcs_tx_wren_o(),             //output          
    .serdes_pcs_tx_afull_i(),            //input           
    .serdes_astat_i()                    //input [5:0]     
);

initial begin
    #100;
    serdes_pll_lock = 1'b1;
    #100;
    serdes_rx_lock = 1'b1;
    #100;
    serdes_data_valid = 1'b1;
end

`ifdef VCS
initial begin
    $fsdbDumpfile("tb.fsdb");
    $fsdbDumpvars;
end
`endif

initial begin
    xgmii_tx_idle;
    wait(block_lock == 1'b1);
    $display("--------%8t:10GBASER PCS Block Lock--------",$realtime);
    repeat(10) begin
        xgmii_tx_idle;
        $display("--------%8t:Send XGMII Frame--------",$realtime);
        xgmii_tx_data;
        xgmii_tx_idle;
    end
    repeat(100) @(posedge xgmii_clk);
    $display("--------%8t:Finish--------",$realtime);
    `ifdef MODELSIM
        $stop;
    `endif
    `ifdef VCS
        $finish;
    `endif
end
    
    
    
task xgmii_tx_idle;
begin
    @(posedge xgmii_clk);
    xgmii_txc <= 8'hff;
    xgmii_txd <= {8{8'h07}};
end
endtask

task xgmii_tx_data;
reg [7:0] tx_data;
begin
    tx_data = 8'h00;
    @(posedge xgmii_clk);
    xgmii_txc <= 8'h01;
    xgmii_txd <= {8'hd5,{6{8'h55}},8'hfb};
    repeat(100) begin
        @(posedge xgmii_clk);
        tx_data <= tx_data + 8'h8;
        xgmii_txc <= 8'h00;
        xgmii_txd <= {(tx_data+8'h7),(tx_data+8'h6),(tx_data+8'h5),(tx_data+8'h4),(tx_data+8'h3),(tx_data+8'h2),(tx_data+8'h1),(tx_data+8'h0)};
    end
    @(posedge xgmii_clk);
    xgmii_txc <= 8'hff;
    xgmii_txd <= {{7{8'h07}},8'hfd};
end
endtask

endmodule







